@@ -1,6 +1,12 @@
 /* Target-dependent code for the i386.
 
-   Copyright (C) 2001-2023 Free Software Foundation, Inc.
+   Modified by Linaro.
+   Copyright (C) March 2023- Linaro Limited (or its affiliates). All rights reserved.
+   
+   Modified by Arm.
+   Copyright (C) 1995-2023 Arm Limited (or its affiliates). All rights reserved.
+   
+   Copyright (C) 2001-2013 Free Software Foundation, Inc.
 
    This file is part of GDB.
 
@@ -20,13 +26,7 @@
 #ifndef I386_TDEP_H
 #define I386_TDEP_H
 
-#include "gdbarch.h"
-#include "infrun.h"
-#include "expression.h"
-#include <vector>
-#include <utility>
-
-class frame_info_ptr;
+struct frame_info;
 struct gdbarch;
 struct reggroup;
 struct regset;
@@ -58,236 +58,284 @@ enum struct_return
   reg_struct_return		/* Return "short" structures in registers.  */
 };
 
+/* Register classes as defined in the AMD x86-64 psABI.  */
+
+enum amd64_reg_class
+{
+  AMD64_POINTER,
+  AMD64_INTEGER,
+  AMD64_SSE,
+  AMD64_SSEUP,
+  AMD64_X87,
+  AMD64_X87UP,
+  AMD64_COMPLEX_X87,
+  AMD64_NO_CLASS,
+  AMD64_MEMORY
+};
+
 /* i386 architecture specific information.  */
-struct i386_gdbarch_tdep : gdbarch_tdep_base
+struct gdbarch_tdep
 {
   /* General-purpose registers.  */
-  int *gregset_reg_offset = 0;
-  int gregset_num_regs = 0;
-  size_t sizeof_gregset = 0;
+  struct regset *gregset;
+  int *gregset_reg_offset;
+  int gregset_num_regs;
+  size_t sizeof_gregset;
+
+  /* The general-purpose registers used to pass integers when making
+     function calls.  This only applies to amd64, as all parameters
+     are passed through the stack on x86.  */
+  int call_dummy_num_integer_regs;
+  int *call_dummy_integer_regs;
+
+  /* The floating-point registers used to pass floats when making
+     function calls.  */
+  int call_dummy_num_float_regs;
+  int *call_dummy_float_regs;
+
+  /* The floating-point registers used to return float when returning
+     function calls.  */
+  int return_value_num_float_regs;
+  int *return_value_float_regs;
+
+  /* Used on amd64 only.  Classify TYPE according to calling conventions,
+     and store the result in CLASS.  */
+  void (*classify) (struct type *type, enum amd64_reg_class class[2]);
+
+  /* Used on amd64 only.  Non-zero if the first few MEMORY arguments
+     should be passed by pointer.
+
+     More precisely, MEMORY arguments are passed through the stack.
+     But certain architectures require that their address be passed
+     by register as well, if there are still some integer registers
+     available for argument passing.  */
+  int memory_args_by_pointer;
+
+  /* Used on amd64 only.
+
+     If non-zero, then the callers of a function are expected to reserve
+     some space in the stack just before the area where the PC is saved
+     so that the callee may save the integer-parameter registers there.
+     The amount of space is dependent on the list of registers used for
+     integer parameter passing (see component call_dummy_num_integer_regs
+     above).  */
+  int integer_param_regs_saved_in_caller_frame;
 
   /* Floating-point registers.  */
-  size_t sizeof_fpregset = 0;
+  struct regset *fpregset;
+  size_t sizeof_fpregset;
+
+  /* XSAVE extended state.  */
+  struct regset *xstateregset;
 
   /* Register number for %st(0).  The register numbers for the other
      registers follow from this one.  Set this to -1 to indicate the
      absence of an FPU.  */
-  int st0_regnum = 0;
+  int st0_regnum;
 
   /* Number of MMX registers.  */
-  int num_mmx_regs = 0;
+  int num_mmx_regs;
 
   /* Register number for %mm0.  Set this to -1 to indicate the absence
      of MMX support.  */
-  int mm0_regnum = 0;
+  int mm0_regnum;
 
   /* Number of pseudo YMM registers.  */
-  int num_ymm_regs = 0;
+  int num_ymm_regs;
 
   /* Register number for %ymm0.  Set this to -1 to indicate the absence
      of pseudo YMM register support.  */
-  int ymm0_regnum = 0;
+  int ymm0_regnum;
+#ifdef __KNC__
+  /* Number of ZMM registers. */
+  int num_zmm_regs;
 
+  /* Register number for %zmm0. -1 means the absence of ZMM support. */
+  int zmm0_regnum;
+
+  /* Number of opmask registers for k1om. */
+  int num_k_regs;
+
+  /* Register number for the first opmask register. */
+  int k0_regnum;
+#else
   /* Number of AVX512 OpMask registers (K-registers)  */
-  int num_k_regs = 0;
+  int num_k_regs;
 
   /* Register number for %k0.  Set this to -1 to indicate the absence
      of AVX512 OpMask register support.  */
-  int k0_regnum = 0;
+  int k0_regnum;
 
   /* Number of pseudo ZMM registers ($zmm0-$zmm31).  */
-  int num_zmm_regs = 0;
+  int num_zmm_regs;
 
   /* Register number for %zmm0.  Set this to -1 to indicate the absence
      of pseudo ZMM register support.  */
-  int zmm0_regnum = 0;
-
+  int zmm0_regnum;
+#endif
   /* Number of byte registers.  */
-  int num_byte_regs = 0;
+  int num_byte_regs;
 
   /* Register pseudo number for %al.  */
-  int al_regnum = 0;
+  int al_regnum;
 
   /* Number of pseudo word registers.  */
-  int num_word_regs = 0;
+  int num_word_regs;
 
   /* Register number for %ax.  */
-  int ax_regnum = 0;
+  int ax_regnum;
 
   /* Number of pseudo dword registers.  */
-  int num_dword_regs = 0;
+  int num_dword_regs;
 
   /* Register number for %eax.  Set this to -1 to indicate the absence
      of pseudo dword register support.  */
-  int eax_regnum = 0;
+  int eax_regnum;
 
   /* Number of core registers.  */
-  int num_core_regs = 0;
+  int num_core_regs;
 
   /* Number of SSE registers.  */
-  int num_xmm_regs = 0;
+  int num_xmm_regs;
 
+#ifndef __KNC__
   /* Number of SSE registers added in AVX512.  */
-  int num_xmm_avx512_regs = 0;
+  int num_xmm_avx512_regs;
 
   /* Register number of XMM16, the first XMM register added in AVX512.  */
-  int xmm16_regnum = 0;
+  int xmm16_regnum;
 
   /* Number of YMM registers added in AVX512.  */
-  int num_ymm_avx512_regs = 0;
+  int num_ymm_avx512_regs;
 
   /* Register number of YMM16, the first YMM register added in AVX512.  */
-  int ymm16_regnum = 0;
+  int ymm16_regnum;
+#endif
 
   /* Bits of the extended control register 0 (the XFEATURE_ENABLED_MASK
      register), excluding the x87 bit, which are supported by this GDB.  */
 
-  uint64_t xcr0 = 0;
+  uint64_t xcr0;
 
   /* Offset of XCR0 in XSAVE extended state.  */
-  int xsave_xcr0_offset = 0;
+  int xsave_xcr0_offset;
 
   /* Register names.  */
-  const char * const *register_names = nullptr;
+  const char **register_names;
 
   /* Register number for %ymm0h.  Set this to -1 to indicate the absence
      of upper YMM register support.  */
-  int ymm0h_regnum = 0;
+  int ymm0h_regnum;
 
   /* Upper YMM register names.  Only used for tdesc_numbered_register.  */
-  const char * const *ymmh_register_names = nullptr;
+  const char **ymmh_register_names;
 
+#ifndef __KNC__
   /* Register number for %ymm16h.  Set this to -1 to indicate the absence
   of support for YMM16-31.  */
-  int ymm16h_regnum = 0;
+  int ymm16h_regnum;
 
   /* YMM16-31 register names.  Only used for tdesc_numbered_register.  */
-  const char * const *ymm16h_register_names = nullptr;
+  const char **ymm16h_register_names;
 
   /* Register number for %bnd0r.  Set this to -1 to indicate the absence
      bound registers.  */
-  int bnd0r_regnum = 0;
+  int bnd0r_regnum;
 
   /* Register number for pseudo register %bnd0.  Set this to -1 to indicate the absence
      bound registers.  */
-  int bnd0_regnum = 0;
+  int bnd0_regnum;
 
   /* Register number for %bndcfgu. Set this to -1 to indicate the absence
      bound control registers.  */
-  int bndcfgu_regnum = 0;
+  int bndcfgu_regnum;
 
   /* MPX register names.  Only used for tdesc_numbered_register.  */
-  const char * const *mpx_register_names = nullptr;
+  const char **mpx_register_names;
 
   /* Register number for %zmm0h.  Set this to -1 to indicate the absence
      of ZMM_HI256 register support.  */
-  int zmm0h_regnum = 0;
+  int zmm0h_regnum;
 
   /* OpMask register names.  */
-  const char * const *k_register_names = nullptr;
+  const char **k_register_names;
 
   /* ZMM register names.  Only used for tdesc_numbered_register.  */
-  const char * const *zmmh_register_names = nullptr;
+  const char **zmmh_register_names;
 
   /* XMM16-31 register names.  Only used for tdesc_numbered_register.  */
-  const char * const *xmm_avx512_register_names = nullptr;
+  const char **xmm_avx512_register_names;
 
   /* YMM16-31 register names.  Only used for tdesc_numbered_register.  */
-  const char * const *ymm_avx512_register_names = nullptr;
+  const char **ymm_avx512_register_names;
 
-  /* Number of PKEYS registers.  */
-  int num_pkeys_regs = 0;
+  /* Number of PKEYS registers  */
+  int num_pkeys_regs;
 
-  /* Register number for PKRU register.  */
-  int pkru_regnum = 0;
+  /* Register number for PKRU register  */
+  int pkru_regnum;
 
-  /* PKEYS register names.  */
-  const char * const *pkeys_register_names = nullptr;
-
-  /* Register number for AMX tilecfg register, including pseudo register.  */
-  int tilecfg_regnum = 0;
-  int tilecfg_raw_regnum = 0;
-
-  /* Number of tilecfg registers, including pseudo register.  */
-  int num_tilecfg_regs = 0;
-  int num_tilecfg_raw_regs = 0;
-
-  /* Register number for AMX tmm register, including pseudo registers.  */
-  int tmm_regnum = 0;
-  int tiledata_regnum = 0;
-
-  /* Number of AMX tmm registers, including pseudo registers.  */
-  int num_tmm_regs = 0;
-  int num_tiledata_regs = 0;
-
-  /* AMX register names.  */
-  const char * const *tilecfg_raw_register_names = nullptr;
-  const char * const *tilecfg_register_names = nullptr;
-  const char * const *tmm_register_names = nullptr;
-  const char * const *tiledata_register_names = nullptr;
-
-  /* Register number for %fsbase.  Set this to -1 to indicate the
-     absence of segment base registers.  */
-  int fsbase_regnum = 0;
+  /* PKEYS register names  */
+  const char **pkeys_register_names;
+#endif
 
   /* Target description.  */
-  const struct target_desc *tdesc = nullptr;
+  const struct target_desc *tdesc;
 
   /* Register group function.  */
-  gdbarch_register_reggroup_p_ftype *register_reggroup_p = nullptr;
+  const void *register_reggroup_p;
 
   /* Offset of saved PC in jmp_buf.  */
-  int jb_pc_offset = 0;
+  int jb_pc_offset;
 
   /* Convention for returning structures.  */
-  enum struct_return struct_return {};
+  enum struct_return struct_return;
 
   /* Address range where sigtramp lives.  */
-  CORE_ADDR sigtramp_start = 0;
-  CORE_ADDR sigtramp_end = 0;
+  CORE_ADDR sigtramp_start;
+  CORE_ADDR sigtramp_end;
 
   /* Detect sigtramp.  */
-  int (*sigtramp_p) (frame_info_ptr) = nullptr;
+  int (*sigtramp_p) (struct frame_info *);
 
   /* Get address of sigcontext for sigtramp.  */
-  CORE_ADDR (*sigcontext_addr) (frame_info_ptr) = nullptr;
+  CORE_ADDR (*sigcontext_addr) (struct frame_info *);
 
   /* Offset of registers in `struct sigcontext'.  */
-  int *sc_reg_offset = 0;
-  int sc_num_regs = 0;
+  int *sc_reg_offset;
+  int sc_num_regs;
 
   /* Offset of saved PC and SP in `struct sigcontext'.  Usage of these
      is deprecated, please use `sc_reg_offset' instead.  */
-  int sc_pc_offset = 0;
-  int sc_sp_offset = 0;
+  int sc_pc_offset;
+  int sc_sp_offset;
 
   /* ISA-specific data types.  */
-  struct type *i386_mmx_type = nullptr;
-  struct type *i386_ymm_type = nullptr;
-  struct type *i386_zmm_type = nullptr;
-  struct type *i386_tmm_type = nullptr;
-  struct type *i386_tilecfg_type = nullptr;
-  struct type *i387_ext_type = nullptr;
-  struct type *i386_bnd_type = nullptr;
+  struct type *i386_mmx_type;
+  struct type *i386_ymm_type;
+#ifndef __KNC__  
+  struct type *i386_zmm_type;
+#endif
+  struct type *i387_ext_type;
+#ifndef __KNC__  
+  struct type *i386_bnd_type;
+#endif
 
   /* Process record/replay target.  */
   /* The map for registers because the AMD64's registers order
      in GDB is not same as I386 instructions.  */
-  const int *record_regmap = nullptr;
+  const int *record_regmap;
   /* Parse intx80 args.  */
-  int (*i386_intx80_record) (struct regcache *regcache) = nullptr;
+  int (*i386_intx80_record) (struct regcache *regcache);
   /* Parse sysenter args.  */
-  int (*i386_sysenter_record) (struct regcache *regcache) = nullptr;
+  int (*i386_sysenter_record) (struct regcache *regcache);
   /* Parse syscall args.  */
-  int (*i386_syscall_record) (struct regcache *regcache) = nullptr;
-
-  /* Regsets. */
-  const struct regset *fpregset = nullptr;
+  int (*i386_syscall_record) (struct regcache *regcache);
 };
 
 /* Floating-point registers.  */
 
-/* All FPU control registers (except for FIOFF and FOOFF) are 16-bit
+/* All FPU control regusters (except for FIOFF and FOOFF) are 16-bit
    (at most) in the FPU, but are zero-extended to 32 bits in GDB's
    register cache.  */
 
@@ -320,6 +368,7 @@ enum i386_regnum
   I386_MXCSR_REGNUM = 40,	/* %mxcsr */ 
   I386_YMM0H_REGNUM,		/* %ymm0h */
   I386_YMM7H_REGNUM = I386_YMM0H_REGNUM + 7,
+#ifndef __KNC__
   I386_BND0R_REGNUM,
   I386_BND3R_REGNUM = I386_BND0R_REGNUM + 3,
   I386_BNDCFGU_REGNUM,
@@ -327,12 +376,8 @@ enum i386_regnum
   I386_K0_REGNUM,		/* %k0 */
   I386_K7_REGNUM = I386_K0_REGNUM + 7,
   I386_ZMM0H_REGNUM,		/* %zmm0h */
-  I386_ZMM7H_REGNUM = I386_ZMM0H_REGNUM + 7,
-  I386_PKRU_REGNUM,
-  I386_AMX_TILECFG_RAW_REGNUM,
-  I386_AMX_TILEDATA_REGNUM,
-  I386_FSBASE_REGNUM,
-  I386_GSBASE_REGNUM
+  I386_ZMM7H_REGNUM = I386_ZMM0H_REGNUM + 7
+#endif
 };
 
 /* Register numbers of RECORD_REGMAP.  */
@@ -370,13 +415,13 @@ enum record_i386_regnum
 
 #define I386_SSE_NUM_REGS	(I386_MXCSR_REGNUM + 1)
 #define I386_AVX_NUM_REGS	(I386_YMM7H_REGNUM + 1)
+#ifndef __KNC__
 #define I386_MPX_NUM_REGS	(I386_BNDSTATUS_REGNUM + 1)
 #define I386_AVX512_NUM_REGS	(I386_ZMM7H_REGNUM + 1)
-#define I386_PKEYS_NUM_REGS	(I386_PKRU_REGNUM + 1)
-#define I386_NUM_REGS		(I386_GSBASE_REGNUM + 1)
+#endif
 
 /* Size of the largest register.  */
-#define I386_MAX_REGISTER_SIZE	8192
+#define I386_MAX_REGISTER_SIZE	64
 
 /* Types for i386-specific registers.  */
 extern struct type *i387_ext_type (struct gdbarch *gdbarch);
@@ -386,16 +431,18 @@ extern int i386_byte_regnum_p (struct gdbarch *gdbarch, int regnum);
 extern int i386_word_regnum_p (struct gdbarch *gdbarch, int regnum);
 extern int i386_dword_regnum_p (struct gdbarch *gdbarch, int regnum);
 extern int i386_xmm_regnum_p (struct gdbarch *gdbarch, int regnum);
+#ifndef __KNC__
 extern int i386_xmm_avx512_regnum_p (struct gdbarch * gdbarch, int regnum);
+#endif
 extern int i386_ymm_regnum_p (struct gdbarch *gdbarch, int regnum);
+#ifndef __KNC__
 extern int i386_ymm_avx512_regnum_p (struct gdbarch *gdbarch, int regnum);
 extern int i386_bnd_regnum_p (struct gdbarch *gdbarch, int regnum);
 extern int i386_k_regnum_p (struct gdbarch *gdbarch, int regnum);
 extern int i386_zmm_regnum_p (struct gdbarch *gdbarch, int regnum);
 extern int i386_zmmh_regnum_p (struct gdbarch *gdbarch, int regnum);
-extern bool i386_pkru_regnum_p (struct gdbarch *gdbarch, int regnum);
-extern bool i386_tilecfg_regnum_p (struct gdbarch *gdbarch, int regnum);
-extern bool i386_tmm_regnum_p (struct gdbarch *gdbarch, int regnum);
+extern int i386_pkru_regnum_p (struct gdbarch *gdbarch, int regnum);
+#endif
 
 extern const char *i386_pseudo_register_name (struct gdbarch *gdbarch,
 					      int regnum);
@@ -403,7 +450,7 @@ extern struct type *i386_pseudo_register_type (struct gdbarch *gdbarch,
 					       int regnum);
 
 extern void i386_pseudo_register_read_into_value (struct gdbarch *gdbarch,
-						  readable_regcache *regcache,
+						  struct regcache *regcache,
 						  int regnum,
 						  struct value *result);
 
@@ -411,10 +458,6 @@ extern void i386_pseudo_register_write (struct gdbarch *gdbarch,
 					struct regcache *regcache,
 					int regnum, const gdb_byte *buf);
 
-extern int i386_ax_pseudo_register_collect (struct gdbarch *gdbarch,
-					    struct agent_expr *ax,
-					    int regnum);
-
 /* Segment selectors.  */
 #define I386_SEL_RPL	0x0003  /* Requester's Privilege Level mask.  */
 #define I386_SEL_UPL	0x0003	/* User Privilige Level.  */
@@ -425,30 +468,17 @@ extern int i386_ax_pseudo_register_collect (struct gdbarch *gdbarch,
 #define I386_MAX_INSN_LEN (16)
 
 /* Functions exported from i386-tdep.c.  */
-extern CORE_ADDR i386_pe_skip_trampoline_code (frame_info_ptr frame,
+extern CORE_ADDR i386_pe_skip_trampoline_code (struct frame_info *frame,
 					       CORE_ADDR pc, char *name);
 extern CORE_ADDR i386_skip_main_prologue (struct gdbarch *gdbarch,
 					  CORE_ADDR pc);
 
-/* The "push_dummy_call" gdbarch method, optionally with the thiscall
-   calling convention.  */
-extern CORE_ADDR i386_thiscall_push_dummy_call (struct gdbarch *gdbarch,
-						struct value *function,
-						struct regcache *regcache,
-						CORE_ADDR bp_addr,
-						int nargs, struct value **args,
-						CORE_ADDR sp,
-						function_call_return_method
-						return_method,
-						CORE_ADDR struct_addr,
-						bool thiscall);
-
 /* Return whether the THIS_FRAME corresponds to a sigtramp routine.  */
-extern int i386_sigtramp_p (frame_info_ptr this_frame);
+extern int i386_sigtramp_p (struct frame_info *this_frame);
 
 /* Return non-zero if REGNUM is a member of the specified group.  */
 extern int i386_register_reggroup_p (struct gdbarch *gdbarch, int regnum,
-				     const struct reggroup *group);
+				     struct reggroup *group);
 
 /* Supply register REGNUM from the general-purpose register set REGSET
    to register cache REGCACHE.  If REGNUM is -1, do this for all
@@ -457,28 +487,28 @@ extern void i386_supply_gregset (const struct regset *regset,
 				 struct regcache *regcache, int regnum,
 				 const void *gregs, size_t len);
 
-/* General-purpose register set. */
-extern const struct regset i386_gregset;
+/* Collect register REGNUM from the register cache REGCACHE and store
+   it in the buffer specified by GREGS and LEN as described by the
+   general-purpose register set REGSET.  If REGNUM is -1, do this for
+   all registers in REGSET.  */
+extern void i386_collect_gregset (const struct regset *regset,
+				  const struct regcache *regcache,
+				  int regnum, void *gregs, size_t len);
 
-/* Floating-point register set. */
-extern const struct regset i386_fpregset;
+/* Return the appropriate register set for the core section identified
+   by SECT_NAME and SECT_SIZE.  */
+extern const struct regset *
+  i386_regset_from_core_section (struct gdbarch *gdbarch,
+				 const char *sect_name, size_t sect_size);
 
-/* Default iterator over core file register note sections.  */
-extern void
-  i386_iterate_over_regset_sections (struct gdbarch *gdbarch,
-				     iterate_over_regset_sections_cb *cb,
-				     void *cb_data,
-				     const struct regcache *regcache);
 
-typedef buf_displaced_step_copy_insn_closure
-  i386_displaced_step_copy_insn_closure;
-
-extern displaced_step_copy_insn_closure_up i386_displaced_step_copy_insn
+extern struct displaced_step_closure *i386_displaced_step_copy_insn
   (struct gdbarch *gdbarch, CORE_ADDR from, CORE_ADDR to,
    struct regcache *regs);
-extern void i386_displaced_step_fixup
-  (struct gdbarch *gdbarch, displaced_step_copy_insn_closure *closure,
-   CORE_ADDR from, CORE_ADDR to, regcache *regs);
+extern void i386_displaced_step_fixup (struct gdbarch *gdbarch,
+				       struct displaced_step_closure *closure,
+				       CORE_ADDR from, CORE_ADDR to,
+				       struct regcache *regs);
 
 /* Initialize a basic ELF architecture variant.  */
 extern void i386_elf_init_abi (struct gdbarch_info, struct gdbarch *);
@@ -486,24 +516,28 @@ extern void i386_elf_init_abi (struct gdbarch_info, struct gdbarch *);
 /* Initialize a SVR4 architecture variant.  */
 extern void i386_svr4_init_abi (struct gdbarch_info, struct gdbarch *);
 
-/* Convert SVR4 register number REG to the appropriate register number
-   used by GDB.  */
-extern int i386_svr4_reg_to_regnum (struct gdbarch *gdbarch, int reg);
-
 extern int i386_process_record (struct gdbarch *gdbarch,
-				struct regcache *regcache, CORE_ADDR addr);
-extern const struct target_desc *i386_target_description (uint64_t xcr0,
-							  bool segments);
-
-/* Return true iff the current target is MPX enabled.  */
-extern int i386_mpx_enabled (void);
+                                struct regcache *regcache, CORE_ADDR addr);
+struct gdbarch *i386_gdbarch_init (struct gdbarch_info,
+                                   struct gdbarch_list *);
 
+#ifndef __KNC__
+/* Verify if target is MPX enabled.  */
+extern int i386_mpx_enabled (void);
+#endif
 
-/* Functions and variables exported from i386-bsd-tdep.c.  */
+
+
+/* Functions and variables exported from i386bsd-tdep.c.  */
 
 extern void i386bsd_init_abi (struct gdbarch_info, struct gdbarch *);
+extern CORE_ADDR i386fbsd_sigtramp_start_addr;
+extern CORE_ADDR i386fbsd_sigtramp_end_addr;
 extern CORE_ADDR i386obsd_sigtramp_start_addr;
 extern CORE_ADDR i386obsd_sigtramp_end_addr;
+extern int i386fbsd4_sc_reg_offset[];
+extern int i386fbsd_sc_reg_offset[];
+extern int i386nbsd_sc_reg_offset[];
 extern int i386obsd_sc_reg_offset[];
 extern int i386bsd_sc_reg_offset[];
 
@@ -512,97 +546,7 @@ extern int i386bsd_sc_reg_offset[];
 extern int i386_stap_is_single_operand (struct gdbarch *gdbarch,
 					const char *s);
 
-extern expr::operation_up i386_stap_parse_special_token
-     (struct gdbarch *gdbarch, struct stap_parse_info *p);
-
-/* AMX utilities.  */
-
-/* TILECFG register.
-   0       palette
-   1       start_row
-   2-15    reserved, must be zero
-   16-17   tile0.colsb Tile 0 bytes per row.
-   18-19   tile1.colsb Tile 1 bytes per row.
-   20-21   tile2.colsb Tile 2 bytes per row.
-   ...     (sequence continues)
-   30-31   tile7.colsb Tile 7 bytes per row.
-   32-47   reserved, must be zero
-   48      tile0.rows Tile 0 rows.
-   49      tile1.rows Tile 1 rows.
-   50      tile2.rows Tile 2 rows.
-   ...     (sequence continues)
-   55      tile7.rows Tile 7 rows.
-   56-63   reserved, must be zero.  */
-
-/* TILECFG class representing the AMX Tilecfg register.  */
-
-class tilecfg_reg
-{
-public:
-  tilecfg_reg ()
-      : columns_and_rows (
-	  std::vector<std::pair<uint16_t, uint8_t>> (MAX_NAMES, { 0, 0 }))
-  {
-  }
-
-  /* Construct it from raw tilecfg data.  */
-  explicit tilecfg_reg (uint8_t *raw_tilecfg);
-
-  ~tilecfg_reg () noexcept = default;
-  tilecfg_reg (const tilecfg_reg &t) = default;
-  tilecfg_reg (tilecfg_reg &&t) noexcept = default;
-
-  tilecfg_reg &operator= (tilecfg_reg &&t) noexcept = default;
-
-  /* Get number of configured bytes per row for tile p.  */
-  inline uint16_t
-  bytes_per_row (uint8_t p) const
-  {
-    gdb_assert (columns_and_rows.size () > p);
-    return columns_and_rows[p].first;
-  }
-
-  /* Get number of configured rows for tile p.  */
-  inline uint8_t
-  rows (uint8_t p) const
-  {
-    gdb_assert (columns_and_rows.size () > p);
-    return columns_and_rows[p].second;
-  }
-
-  bool
-  operator== (const tilecfg_reg &t) const
-  {
-    return palette == t.palette && start_row == t.start_row
-	   && columns_and_rows == t.columns_and_rows;
-  }
-
-  bool
-  operator!= (const tilecfg_reg &t) const
-  {
-    return !(*this == t);
-  }
-
-  /* Offsets for reading from TILEDATA.  */
-  static const uint16_t COLUMN_MEMORY_OFFSET = 16;
-  static const uint16_t ROW_MEMORY_OFFSET = 48;
-
-  /* Maximum possible values for the current target.  */
-  static const uint16_t MAX_PALETTE = 1;
-  static const uint16_t MAX_NAMES = 8;
-  static const uint16_t MAX_ROWS = 16;
-  static const uint16_t MAX_BYTES_PER_ROW = 64;
-  static const uint16_t MAX_BYTES_PER_TILE = 1024;
-
-  /* Palette id entry.  */
-  uint8_t palette = 0;
-
-  /* start_row entry.  */
-  uint8_t start_row = 0;
-
-private:
-  /* This stores the colsb and rows entries.  */
-  std::vector<std::pair<uint16_t, uint8_t>> columns_and_rows;
-};
+extern int i386_stap_parse_special_token (struct gdbarch *gdbarch,
+					  struct stap_parse_info *p);
 
 #endif /* i386-tdep.h */
